# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ...core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class OperationResult(UniversalBaseModel):
    message: typing.Optional[str] = pydantic.Field(default=None)
    """
    Message describing the result. If the virtual card link was sent successfully, this contains the email address to which the link was sent.
    """

    success: bool = pydantic.Field()
    """
    Indicates whether the operation was successful.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
