# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata
from .is_success import IsSuccess
from .page_identifier import PageIdentifier
from .payabli_api_response_0_response_data import PayabliApiResponse0ResponseData
from .response_text import ResponseText


class PayabliApiResponse0(UniversalBaseModel):
    """
    General response for certain `moneyIn` and `moneyOut` endpoints.
    """

    is_success: typing_extensions.Annotated[typing.Optional[IsSuccess], FieldMetadata(alias="isSuccess")] = None
    page_identifier: typing_extensions.Annotated[
        typing.Optional[PageIdentifier], FieldMetadata(alias="pageIdentifier")
    ] = None
    response_data: typing_extensions.Annotated[
        typing.Optional[PayabliApiResponse0ResponseData], FieldMetadata(alias="responseData")
    ] = None
    response_text: typing_extensions.Annotated[ResponseText, FieldMetadata(alias="responseText")]

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
